# MOBSTERm
`MOBSTERm` is a package that implements a Bayesian model to perform multivariate subclonal deconvolution, allowing to detect neutral, private and selected clonal mutations in multi-region and longitunal cancer datasets.
